@@ -1,5 +1,5 @@
 """
- * Copyright 2013-2021 Erudika. https://erudika.com
+ * Copyright 2013-2023 Erudika. https://erudika.com
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -123,8 +123,8 @@ class ParaClient:
             parts = token.split(".")
             decoded = json.loads(base64.b64decode(parts[1] + "==").decode("utf-8"))
             if decoded and "exp" in decoded:
-                self.__tokenKeyExpires = decoded["exp"]
-                self.__tokenKeyNextRefresh = decoded["refresh"]
+                self.__tokenKeyExpires = decoded.get("exp")
+                self.__tokenKeyNextRefresh = decoded.get("refresh")
             else:
                 del self.__tokenKeyExpires
                 del self.__tokenKeyNextRefresh
